@@ -16,7 +16,7 @@ use Log::Log4perl::Appender;
 
 use constant _INTERNAL_DEBUG => 1;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
    # set this to '1' if you're using a wrapper
    # around Log::Log4perl
@@ -644,8 +644,8 @@ In this case, C<Log::Log4perl> will walk up the class hierarchy
 defined somewhere. In the case above, the log level at the root
 (root I<always> defines a log level, but not necessarily an appender)
 defines that 
-the log level is supposed to be C<ERROR> -- meaning that I<debug>
-and I<info> messages are suppressed.
+the log level is supposed to be C<ERROR> -- meaning that I<DEBUG>
+and I<INFO> messages are suppressed.
 
 =head2 Log Levels
 
@@ -901,7 +901,7 @@ how it works:
     log4j.appender.A1.layout=org.apache.log4j.PatternLayout
     log4j.appender.A1.layout.ConversionPattern=%-4r %-5p %c %x - %m%n
 
-This enables messages of priority C<debug> or higher in the root
+This enables messages of priority C<DEBUG> or higher in the root
 hierarchy and has the system write them to the console. 
 C<ConsoleAppender> is a Java appender, but C<Log::Log4perl> jumps
 through a significant number of hoops internally to map these to their
@@ -1205,15 +1205,15 @@ Here's how it works:
     # Turn off logging in a lower-level category while keeping
     # it active in higher-level categories.
     ############################################################
-    log4perl.rootLogger=debug, LOGFILE
-    log4perl.logger.deep.down.the.hierarchy = error, LOGFILE
+    log4perl.rootLogger=DEBUG, LOGFILE
+    log4perl.logger.deep.down.the.hierarchy = ERROR, LOGFILE
 
     # ... Define appenders ...
 
 This way, log messages issued from within 
 C<Deep::Down::The::Hierarchy> and below will be
-logged only if they're C<error> or worse, while in all other system components
-even C<debug> messages will be logged.
+logged only if they're C<ERROR> or worse, while in all other system components
+even C<DEBUG> messages will be logged.
 
 =head2 Return Values
 
@@ -1421,7 +1421,7 @@ a hash, you can just as well initialize C<Log::Log4perl> with
 a reference to it:
 
     my %key_value_pairs = (
-        "log4perl.rootLogger"       => "error, LOGFILE",
+        "log4perl.rootLogger"       => "ERROR, LOGFILE",
         "log4perl.appender.LOGFILE" => "Log::Log4perl::Appender::File",
         ...
     );
@@ -2502,6 +2502,7 @@ our
     Hutton Davidson <Davidson.Hutton@ftid.com>
     Chris R. Donnelly <cdonnelly@digitalmotorworks.com>
     Matisse Enzer
+    Hugh Esco
     James FitzGibbon <james.fitzgibbon@target.com>
     Carl Franks
     Dennis Gregorovic <dgregor@redhat.com>
