@@ -7,6 +7,7 @@ our @ISA = qw(Log::Log4perl::Appender);
 use warnings;
 use strict;
 use Log::Log4perl::Config::Watch;
+use constant _INTERNAL_DEBUG => 0;
 
 ##################################################
 sub new {
@@ -22,6 +23,8 @@ sub new {
         utf8      => undef,
         recreate  => 0,
         recreate_check_interval => 30,
+        recreate_signal         => undef,
+        recreate_pid_write      => undef,
         @options,
     };
 
@@ -30,6 +33,15 @@ sub new {
 
     bless $self, $class;
 
+    if($self->{recreate_pid_write}) {
+        print "Creating pid file",
+              " $self->{recreate_pid_write}\n" if _INTERNAL_DEBUG;
+        open FILE, ">$self->{recreate_pid_write}" or 
+            die "Cannot open $self->{recreate_pid_write}";
+        print FILE "$$\n";
+        close FILE;
+    }
+
         # This will die() if it fails
     $self->file_open();
 
@@ -69,7 +81,10 @@ sub file_open {
     if($self->{recreate}) {
         $self->{watcher} = Log::Log4perl::Config::Watch->new(
             file           => $self->{filename},
-            check_interval => $self->{recreate_check_interval},
+            ($self->{recreate_check_interval} ?
+              (check_interval => $self->{recreate_check_interval}) : ()),
+            ($self->{recreate_check_signal} ?
+              (signal => $self->{recreate_check_signal}) : ()),
         );
     }
 
@@ -105,6 +120,9 @@ sub file_switch {
 ##################################################
     my($self, $new_filename) = @_;
 
+    print "Switching file from $self->{filename} to $new_filename\n" if
+        _INTERNAL_DEBUG;
+
     $self->file_close();
     $self->{filename} = $new_filename;
     $self->file_open();
@@ -116,8 +134,15 @@ sub log {
     my($self, %params) = @_;
 
     if($self->{recreate}) {
-        if($self->{watcher}->file_has_moved()) {
-            $self->file_switch($self->{filename});
+        if($self->{recreate_check_signal}) {
+            if($self->{watcher}->{signal_caught}) {
+                $self->{watcher}->{signal_caught} = 0;
+                $self->file_switch($self->{filename});
+            }
+        } else {
+            if($self->{watcher}->file_has_moved()) {
+                $self->file_switch($self->{filename});
+            }
         }
     }
 
@@ -255,6 +280,24 @@ has been moved or deleted. If this is undesirable,
 setting C<recreate_check_interval> to 0 will have the appender
 appender check the file with I<every> call to C<log()>.
 
+=item recreate_signal
+
+In C<recreate> mode, if this option is set to a signal name
+(e.g. "USR1"), the appender will recreate a missing logfile
+when it receives the signal. It uses less resources than constant
+polling. The usual limitation with perl's signal handling apply.
+Check the FAQ for using this option with the log rotating 
+utility C<newsyslog>.
+
+=item recreate_pid_write
+
+The popular log rotating utility C<newsyslog> expects a pid file
+in order to send the application a signal when its logs have
+been rotated. This option expects a path to a file where the pid
+of the currently running application gets written to.
+Check the FAQ for using this option with the log rotating 
+utility C<newsyslog>.
+
 =back
 
 Design and implementation of this module has been greatly inspired by
