@@ -17,6 +17,7 @@ sub new {
 
     my $self = { file            => "",
                  check_interval  => 30,
+                 l4p_internal    => 0,
                  signal          => undef,
                  %options,
                  _last_checked_at => 0,
@@ -27,12 +28,20 @@ sub new {
 
     if($self->{signal}) {
             # We're in signal mode, set up the handler
-        $SIG{$self->{signal}} = sub { $SIGNAL_CAUGHT = 1; };
+        print "Setting up signal handler for '$self->{signal}'\n" if
+            _INTERNAL_DEBUG;
+        $SIG{$self->{signal}} = sub { 
+            $self->{signal_caught} = 1; 
+            print "Caught signal\n" if _INTERNAL_DEBUG;
+            $SIGNAL_CAUGHT = 1 if $self->{l4p_internal};
+        };
             # Reset the marker. The handler is going to modify it.
-        $SIGNAL_CAUGHT = 0;
+        $self->{signal_caught} = 0;
+        $SIGNAL_CAUGHT = 0 if $self->{l4p_internal};
     } else {
             # Just called to initialize
-        $self->change_detected();
+        $self->change_detected(undef, 1);
+        $self->file_has_moved(undef, 1);
     }
 
     return $self;
@@ -62,42 +71,97 @@ sub check_interval {
     return $self->{check_interval};
 }
 
+###########################################
+sub file_has_moved {
+###########################################
+    my($self, $time, $force) = @_;
+
+    my $task = sub {
+        my @stat = stat($self->{file});
+
+        my $has_moved = 0;
+
+        if(! $stat[0]) {
+            # The file's gone, obviously it got moved or deleted.
+            print "File is gone\n" if _INTERNAL_DEBUG;
+            return 1;
+        }
+
+        my $current_inode = "$stat[0]:$stat[1]";
+        print "Current inode: $current_inode\n" if _INTERNAL_DEBUG;
+
+        if(exists $self->{_file_inode} and 
+            $self->{_file_inode} ne $current_inode) {
+            print "Inode changed from $self->{_file_inode} to ",
+                  "$current_inode\n" if _INTERNAL_DEBUG;
+            $has_moved = 1;
+        }
+
+        $self->{_file_inode} = $current_inode;
+        return $has_moved;
+    };
+
+    return $self->check($time, $task, $force);
+}
+
 ###########################################
 sub change_detected {
 ###########################################
-    my($self, $time) = @_;
+    my($self, $time, $force) = @_;
+
+    my $task = sub {
+        my @stat = stat($self->{file});
+        my $new_timestamp = $stat[9];
+
+        if(! defined $new_timestamp) {
+            if($self->{l4p_internal}) {
+                # The file is gone? Let it slide, we don't want L4p to re-read
+                # the config now, it's gonna die.
+                return undef;
+            }
+            return 1;
+        }
+
+        if($new_timestamp > $self->{_last_timestamp}) {
+            $self->{_last_timestamp} = $new_timestamp;
+            print "Change detected (store=$new_timestamp)!\n" 
+                  if _INTERNAL_DEBUG;
+            return 1; # Has changed
+        }
+           
+        print "Hasn't changed (file=$new_timestamp ",
+              "stored=$self->{_last_timestamp})!\n" if _INTERNAL_DEBUG;
+        return "";  # Hasn't changed
+    };
+
+    return $self->check($time, $task, $force);
+}
+
+###########################################
+sub check {
+###########################################
+    my($self, $time, $task, $force) = @_;
 
     $time = time() unless defined $time;
 
     print "Calling change_detected (time=$time)\n" if _INTERNAL_DEBUG;
 
         # Do we need to check?
-    if($self->{_last_checked_at} + 
+    if(!$force and
+       $self->{_last_checked_at} + 
        $self->{check_interval} > $time) {
         print "No need to check\n" if _INTERNAL_DEBUG;
         return ""; # don't need to check, return false
     }
        
-    my $new_timestamp = (stat($self->{file}))[9];
-       # Sometimes, when the file is being updated, obtaining its
-       # timestamp fails. Ignore it, try again later.
-    return "" unless defined $new_timestamp;
-
     $self->{_last_checked_at} = $time;
 
     # Set global var for optimizations in case we just have one watcher
     # (like in Log::Log4perl)
-    $NEXT_CHECK_TIME = $time + $self->{check_interval};
+    $self->{next_check_time} = $time + $self->{check_interval};
+    $NEXT_CHECK_TIME = $self->{next_check_time} if $self->{l4p_internal};
 
-    if($new_timestamp > $self->{_last_timestamp}) {
-        $self->{_last_timestamp} = $new_timestamp;
-        print "Change detected (store=$new_timestamp)!\n" if _INTERNAL_DEBUG;
-        return 1; # Has changed
-    }
-       
-    print "Hasn't changed (file=$new_timestamp ",
-          "stored=$self->{_last_timestamp})!\n" if _INTERNAL_DEBUG;
-    return "";  # Hasn't changed
+    return $task->($time);
 }
 
 1;
@@ -182,12 +246,9 @@ to set up a signal handler. If you call the constructor like
                           signal  => 'HUP'
                   );
 
-then a signal handler like
-
-    $SIG{HUP} = sub { $SIGNAL_CAUGHT = 1; };
-
-will be installed, setting a globally accessible variable 
-C<Log::Log4perl::Config::Watch::SIGNAL_CAUGHT> to a true value when
+then a signal handler will be installed, setting the object's variable 
+C<$self-E<gt>{signal_caught}>
+to a true value when
 the signal arrives. Comes with all the problems that signal handlers
 go along with.
 
